@@ -17,6 +17,12 @@ CookieJar *CookieJar::instance() {
 }
 
 void CookieJar::addCookie(const QNetworkCookie &cookie, const QString &url) {
+#ifdef PHANTOMPY_QT4
+    QList<QNetworkCookie> cookiesList;
+    cookiesList << cookie;
+
+    setCookiesFromUrl(cookiesList, QUrl(url));
+#else
     bool ok = validateCookie(cookie, QUrl(url));
     if (ok) {
         QList<QNetworkCookie> cookiesList;
@@ -24,9 +30,10 @@ void CookieJar::addCookie(const QNetworkCookie &cookie, const QString &url) {
 
         setCookiesFromUrl(cookiesList, QUrl(url));
     } else {
-        qWarning() << "CookieJar::addCookie: Rejected Cookie"
+        qDebug() << "CookieJar::addCookie: Rejected Cookie"
                    << cookie.toRawForm();
     }
+#endif
 }
 
 void CookieJar::addCookieFromMap(const QVariantMap &cookie, const QString &url) {
@@ -82,23 +89,39 @@ void CookieJar::addCookieFromMap(const QVariantMap &cookie) {
                 n_cookie.setExpirationDate(n_expires);
             }
         }
+#ifdef PHANTOMPY_QT4
+        QList<QNetworkCookie> cookiesList;
+        cookiesList << n_cookie;
 
+        setAllCookies(cookiesList);
+#else
         bool ok = insertCookie(n_cookie);
         if (!ok) {
-            qWarning() << "CookieJar::addCookie(2): Rejected Cookie"
+            qDebug() << "CookieJar::addCookie(2): Rejected Cookie"
                        << n_cookie.toRawForm();
         }
+#endif
     }
 }
 
 void CookieJar::addCookiesFromMapList(const QVariantList &cookies, const QString &url) {
-    for(auto i=cookies.cbegin(); i!=cookies.cend(); ++i) {
+    QVariantList::const_iterator i;
+#ifdef PHANTOMPY_QT4
+    for(i=cookies.begin(); i!=cookies.end(); ++i) {
+#else
+    for(i=cookies.cbegin(); i!=cookies.cend(); ++i) {
+#endif
         addCookieFromMap((*i).toMap(), url);
     }
 }
 
 void CookieJar::addCookiesFromMapList(const QVariantList &cookies) {
-    for(auto i=cookies.cbegin(); i!=cookies.cend(); ++i) {
+    QVariantList::const_iterator i;
+#ifdef PHANTOMPY_QT4
+    for(i=cookies.begin(); i!=cookies.end(); ++i) {
+#else
+    for(i=cookies.cbegin(); i!=cookies.cend(); ++i) {
+#endif
         addCookieFromMap((*i).toMap());
     }
 }
