@@ -34,9 +34,8 @@ QString Frame::toHtml() {
     return p_frame->toHtml();
 }
 
-QString Frame::evaluateJavaScript(const QString &js) {
-    QVariant result = p_frame->evaluateJavaScript(js);
-    return result.toString();
+QVariant Frame::evaluateJavaScript(const QString &js) {
+    return p_frame->evaluateJavaScript(js);
 }
 
 QWebElement Frame::findFirstElement(const QString &selector) {
@@ -47,4 +46,16 @@ QWebElementCollection Frame::findAll(const QString &selector) {
     return p_frame->findAllElements(selector);
 }
 
+QString Frame::getUrl() {
+    return p_frame->url().toString();
+}
+
+void Frame::setUrl(const QString &url) {
+    p_frame->setUrl(QUrl(url));
+}
+
+void Frame::load(const QString &url) {
+    p_frame->load(QUrl(url));
+}
+
 }
