@@ -4,7 +4,10 @@
 #include <QtCore>
 #include <QtNetwork>
 #include <QtWebKit>
+#ifndef PHANTOMPY_QT4
 #include <QtWebKitWidgets>
+#endif
+
 
 #include "networkmanager.hpp"
 #include "networkmanagerproxy.hpp"
@@ -31,9 +34,8 @@ public:
     bool hasLoadErrors();
 
     QWebFrame* mainFrame();
+    QWebHistory* history();
 
-    // Methods for get information about
-    // background requests.
     QSet<QString> requestedUrls();
     QVariantMap getResponseByUrl(const QString &url);
 
@@ -58,6 +60,7 @@ private:
 private slots:
     void loadFinished(bool ok);
     void replyReceived(const QVariantMap &reply);
+    void linkClicked(const QUrl &url);
 };
 
 }
