@@ -9,10 +9,9 @@ from . import image
 from . import webelements
 
 
-def open(url, size=(1280, 768)):
-    ctx = context.context()
-    p = page.Page(url=url, size=size, ctx=ctx)
-    p.load()
+def open(url, size=(1280, 768), cookies=[]):
+    p = page.Page(size=size, cookies=cookies)
+    p.load(url)
 
     return p.frame()
 
