@@ -20,9 +20,17 @@ class Frame(object):
 
     @property
     def ptr(self):
-        assert not self._page.is_closed(), "Page closed"
         return self._frame_ptr
 
+    @property
+    def url(self):
+        return util.force_text(lib.ph_frame_get_url(self.ptr))
+
+    @url.setter
+    def url(self, value):
+        #lib.ph_frame_load(self.ptr, util.force_bytes(value))
+        lib.ph_frame_set_url(self.ptr, util.force_bytes(value))
+
     @property
     def page(self):
         return self._page
@@ -31,27 +39,20 @@ class Frame(object):
         return lib.ph_frame_to_html(self.ptr)
 
     def to_image(self, format="PNG", quality=-1):
-        if hasattr(format, "encode"):
-            _format = format.encode("utf-8")
-        else:
-            _format = format
+        _format = util.force_bytes(format)
 
         # Obtain image object pointer
         image_ptr = lib.ph_frame_capture_image(self.ptr, _format, quality)
         return image.Image(image_ptr, format, quality, self)
 
     def evaluate(self, js):
-        if hasattr(js, "encode"):
-            js = js.encode("utf-8")
-
+        js = util.force_bytes(js)
         result = lib.ph_frame_evaluate_javascript(self.ptr, js)
-        return result.decode('utf-8')
+        return json.loads(util.force_text(result))
 
     @util.as_list
     def cssselect(self, selector):
-        if hasattr(selector, "encode"):
-            selector = selector.encode('utf-8')
-
+        selector = util.force_bytes(selector)
         c_ptr = lib.ph_frame_find_all(self.ptr, selector)
         c_size = lib.ph_webcollection_size(c_ptr)
 
@@ -63,51 +64,28 @@ class Frame(object):
 
 
 class Page(object):
-    _context = None
-    _context_own = False
     _size = None
-    _loaded = False
-    _closed = False
     _page_ptr = None
 
-    def __init__(self, url, size=(1280, 768), ctx=None):
-        if ctx is None:
-            self._context = context.Context()
-            self._context_own = True
-        else:
-            self._context = ctx
-
-        self._url = url
+    def __init__(self, size=(1280, 768), cookies=[]):
         self._size = size
 
         self._page_ptr = lib.ph_page_create()
         lib.ph_page_set_viewpoint_size(self.ptr,
                                        self._size[0],
                                        self._size[1])
+        if cookies:
+            self._context.set_cookies(cookies)
 
     @property
     def ptr(self):
-        assert not self._closed, "Page closed"
         return self._page_ptr
 
-    def close(self):
-        assert not self._closed, "Page already closed"
+    def __del__(self):
         lib.ph_page_free(self.ptr)
 
-        if self._context_own:
-            self._context.close()
-
-        self._closed = True
-
-    def is_closed(self):
-        return self._closed
-
-    def load(self):
-        assert not self._loaded, "Page already loaded"
-
-        self._loaded = True
-        result = lib.ph_page_load(self.ptr, self._url.encode('utf-8'))
-
+    def load(self, url):
+        result = lib.ph_page_load(self.ptr, util.force_bytes(url))
         if result != 0:
             raise RuntimeError("Error loading page")
 
@@ -116,9 +94,8 @@ class Page(object):
         return Frame(frame_ptr, self)
 
     def get_requested_urls(self):
-        assert self._loaded, "Page not loaded"
         requested_urls = lib.ph_page_get_requested_urls(self.ptr)
-        return json.loads(requested_urls.decode("utf-8"))
+        return json.loads(util.force_text(requested_urls))
 
     def get_response_by_url(self, url):
         """
@@ -141,8 +118,16 @@ class Page(object):
         for url in self.get_requested_urls():
             yield self.get_response_by_url(url)
 
-
     def get_cookies(self):
-        assert self._loaded, "Page not loaded"
+        """
+        Get all cookies assiociated with a current
+        page url.
+        """
         cookies = lib.ph_page_get_cookies(self.ptr)
         return json.loads(cookies.decode("utf-8"))
+
+    def go_back(self):
+        lib.ph_page_go_back(self.ptr)
+
+    def go_forward(self):
+        lib.ph_page_go_forward(self.ptr)
